==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/es_AR.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Almacenamiento invalido",
    "Unknown error" : "Error desconocido",
    "All files" : "Todos los archivos",
    "Saved" : "Guardado",
    "Home" : "Particular",
    "Close" : "Cerrar",
    "Favorites" : "Favoritos",
    "Upload cancelled." : "La subida fue cancelada",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Imposible cargar {filename} puesto que es un directoro o tiene 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hay suficiente espacio libre. Quiere subir {size1} pero solo quedan {size2}",
    "Uploading..." : "Subiendo...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La subida del archivo está en proceso. Si salís de la página ahora, la subida se cancelará.",
    "Actions" : "Acciones",
    "Download" : "Descargar",
    "Rename" : "Cambiar nombre",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "Files" : "Archivos",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendientes",
    "Unable to determine date" : "No fue posible determinar la fecha",
    "Invalid path" : "Ruta no válida",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "{dirs} and {files}" : "{carpetas} y {archivos}",
    "You don’t have permission to upload or create files here" : "No tienes permisos para subir o crear archivos aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
    "New" : "Nuevo",
    "File name cannot be empty." : "El nombre del archivo no puede quedar vacío.",
    "Your storage is full, files can not be updated or synced anymore!" : "El almacenamiento está lleno, los archivos no se pueden seguir actualizando ni sincronizando",
    "Your storage is almost full ({usedSpacePercent}%)" : "El almacenamiento está casi lleno ({usedSpacePercent}%)",
    "Favorite" : "Favorito",
    "Folder" : "Carpeta",
    "New folder" : "Nueva Carpeta",
    "Upload" : "Subir",
    "A new file or folder has been <strong>created</strong>" : "Un archivo o carpeta ha sido <strong>creado</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un archivo o carpeta ha sido <strong>modificado</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>eliminado</strong>",
    "You created %1$s" : "Has creado %1$s",
    "%2$s created %1$s" : "%2$s creó %1$s",
    "You changed %1$s" : "Modificaste %1$s",
    "%2$s changed %1$s" : "%2$s modificó %1$s",
    "You deleted %1$s" : "Eliminaste %1$s",
    "%2$s deleted %1$s" : "%2$s eliminó %1$s",
    "File handling" : "Tratamiento de archivos",
    "Maximum upload size" : "Tamaño máximo de subida",
    "max. possible: " : "máx. posible:",
    "Save" : "Guardar",
    "Settings" : "Configuración",
    "WebDAV" : "WebDAV",
    "Upload too large" : "El tamaño del archivo que querés subir es demasiado grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que intentás subir sobrepasan el tamaño máximo ",
    "Text file" : "Archivo de texto",
    "Storage is temporarily not available" : "El repositorio no está disponible temporalmente",
    "..." : "...",
    "Unknown user" : "Usuario desconocido"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/es_AR.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "El repositorio no está disponible temporalmente",
    "Storage invalid" : "Almacenamiento invalido",
    "Unknown error" : "Error desconocido",
    "All files" : "Todos los archivos",
    "Home" : "Particular",
    "Close" : "Cerrar",
    "Favorites" : "Favoritos",
    "Upload cancelled." : "La subida fue cancelada",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Imposible cargar {filename} puesto que es un directoro o tiene 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hay suficiente espacio libre. Quiere subir {size1} pero solo quedan {size2}",
    "Uploading..." : "Subiendo...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La subida del archivo está en proceso. Si salís de la página ahora, la subida se cancelará.",
    "Actions" : "Acciones",
    "Download" : "Descargar",
    "Rename" : "Cambiar nombre",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "Files" : "Archivos",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendientes",
    "Unable to determine date" : "No fue posible determinar la fecha",
    "Invalid path" : "Ruta no válida",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "El directorio no está disponible, por favor revisa los registros o contacta al administrador",
    "group" : "grupo",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "{dirs} and {files}" : "{carpetas} y {archivos}",
    "You don’t have permission to upload or create files here" : "No tienes permisos para subir o crear archivos aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
    "New" : "Nuevo",
    "Unknown user" : "Usuario desconocido",
    "\"{name}\" is an invalid file name." : "\"{nombre}\" es un nombre inválido de archivo.",
    "File name cannot be empty." : "El nombre del archivo no puede quedar vacío.",
    "Your storage is full, files can not be updated or synced anymore!" : "El almacenamiento está lleno, los archivos no se pueden seguir actualizando ni sincronizando",
    "Your storage is almost full ({usedSpacePercent}%)" : "El almacenamiento está casi lleno ({usedSpacePercent}%)",
    "Favorite" : "Favorito",
    "Folder" : "Carpeta",
    "New folder" : "Nueva Carpeta",
    "Upload" : "Subir",
    "A new file or folder has been <strong>created</strong>" : "Un archivo o carpeta ha sido <strong>creado</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un archivo o carpeta ha sido <strong>modificado</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>eliminado</strong>",
    "You created %1$s" : "Has creado %1$s",
    "%2$s created %1$s" : "%2$s creó %1$s",
    "You changed %1$s" : "Modificaste %1$s",
    "%2$s changed %1$s" : "%2$s modificó %1$s",
    "You deleted %1$s" : "Eliminaste %1$s",
    "%2$s deleted %1$s" : "%2$s eliminó %1$s",
    "Upload (max. %s)" : "Subir (máx. %s)",
    "Settings" : "Configuración",
    "WebDAV" : "WebDAV",
    "No entries found in this folder" : "No se encontraron entradas en esta carpeta",
    "Select all" : "Seleccionar todos",
    "Upload too large" : "El tamaño del archivo que querés subir es demasiado grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que intentás subir sobrepasan el tamaño máximo ",
    "Text file" : "Archivo de texto",
    "New text file.txt" : "Nuevo archivo de texto.txt"
},
"nplurals=2; plural=(n != 1);");
